<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */

namespace FiloBlu\DisableShop\Block;

use Magento\Catalog\Block\Product\View;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Framework\View\Element\Template;
use Magento\Store\Model\ScopeInterface;

/**
 * Main contact form block
 *
 * @api
 * @since 100.0.2
 */
class InfoForm extends Template
{
    /**
     * @var View
     */
    protected $_product;

    /**
     * InfoForm constructor.
     * @param View $product
     * @param Template\Context $context
     * @param array $data
     */
    public function __construct(
        View $product,
        Template\Context $context,
        array $data = []
    ) {
        parent::__construct($context, $data);
        $this->_product = $product;
        $this->_isScopePrivate = true;
    }

    /**
     * @return string
     * @throws NoSuchEntityException
     */
    public function getFormAction()
    {
        return $this->_storeManager->getStore()->getBaseUrl() . 'askproductinfo/index/productinfo';
    }

    /**
     * @return string
     */
    public function getProductSku()
    {
        return $this->_product->getProduct()->getSku();
    }

    /**
     * @return string
     */
    public function getProductName()
    {
        return $this->_product->getProduct()->getName();
    }

    public function isProductDisabled()
    {
        return $this->_product->getProduct()->getDisableShop() == 1;
    }

    /**
     * @return mixed
     */
    public function getInfoTitle()
    {
        return $this->_scopeConfig->getValue(
            'filoblu_disableshop_section/ask_info/ask_info_title',
            ScopeInterface::SCOPE_STORE
        );
    }

    /**
     * @return mixed
     */
    public function getInfoPrivacy()
    {
        return $this->_scopeConfig->getValue(
            'filoblu_disableshop_section/ask_info/ask_info_privacy',
            ScopeInterface::SCOPE_STORE
        );
    }

    /**
     * @return mixed
     */
    public function isNewsletterEnabled()
    {
        return $this->_scopeConfig->getValue(
            'filoblu_disableshop_section/ask_info/ask_info_newsletter',
            ScopeInterface::SCOPE_STORE
        );
    }

    /**
     * @return mixed
     */
    public function getPrivacyBlock()
    {
        return $this->_scopeConfig->getValue(
            'filoblu_disableshop_section/ask_info/ask_info_newsletter_privacy',
            ScopeInterface::SCOPE_STORE
        );
    }
}
